==> dif-database-repository-2.2.0-1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IAuditService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.dem.managers.impl.model.dao.IAuditLogDAO;
import pt.digitalis.dif.dem.managers.impl.model.dao.IAuditLogDetailDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.model.data.AuditLogDetail;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IAuditService {

    /**
     * Obtains a new AuditLog DAO
     *
     * @return A new IAuditLogDAO
     */
    public IAuditLogDAO getAuditLogDAO();

    /**
     * Obtains a new DataSet for the AuditLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLog> getAuditLogDataSet();

    /**
     * Obtains a new AuditLogDetail DAO
     *
     * @return A new IAuditLogDetailDAO
     */
    public IAuditLogDetailDAO getAuditLogDetailDAO();

    /**
     * Obtains a new DataSet for the AuditLogDetail entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLogDetail> getAuditLogDetailDataSet();

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}

==> dif-database-repository-2.3.2-sources.jar: pt/digitalis/dif/dem/managers/impl/model/IAuditService.java <==
package pt.digitalis.dif.dem.managers.impl.model;

import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.utils.common.IBeanAttributes;
import pt.digitalis.dif.dem.managers.impl.model.dao.IAccessLogDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.AccessLog;
import pt.digitalis.dif.dem.managers.impl.model.dao.IAuditLogDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.AuditLog;
import pt.digitalis.dif.dem.managers.impl.model.dao.IAuditLogDetailDAO;
import pt.digitalis.dif.dem.managers.impl.model.data.AuditLogDetail;

/**
 * NOTE: This file is auto generated and will be overwrite in a future file generation.
 */
public interface IAuditService {

	/**
	 * Obtains a new AccessLog DAO
	 *
	 * @return A new IAccessLogDAO
	 */
    public IAccessLogDAO getAccessLogDAO();

    /**
     * Obtains a new DataSet for the AccessLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AccessLog> getAccessLogDataSet();

	/**
	 * Obtains a new AuditLog DAO
	 *
	 * @return A new IAuditLogDAO
	 */
    public IAuditLogDAO getAuditLogDAO();

    /**
     * Obtains a new DataSet for the AuditLog entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLog> getAuditLogDataSet();

	/**
	 * Obtains a new AuditLogDetail DAO
	 *
	 * @return A new IAuditLogDetailDAO
	 */
    public IAuditLogDetailDAO getAuditLogDetailDAO();

    /**
     * Obtains a new DataSet for the AuditLogDetail entity
     *
     * @return A new IDataSet instance
     */
    public IDataSet<AuditLogDetail> getAuditLogDetailDataSet();


    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz);

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public IDataSet<? extends IBeanAttributes> getDataSet(String entityName);
}
